@@ -11,6 +11,7 @@
 	data.frame(dim = 'acceleration', unit = 'km_per_sec2', std = 1e-3),
 	data.frame(dim = 'acceleration', unit = 'grav', std = 1/9.80665),
 	data.frame(dim = 'acceleration', unit = 'inch_per_sec2', std = 100/2.54),
+	data.frame(dim = 'acceleration', unit = 'in_per_sec2', std = 100/2.54),
 	data.frame(dim = 'acceleration', unit = 'ft_per_sec2', std = 100/2.54/12),
 	data.frame(dim = 'acceleration', unit = 'mi_per_sec2', std = 100/2.54/12/5280),
 	data.frame(dim = 'acceleration', unit = 'kph_per_sec', std = 1e-3*3600),
@@ -52,16 +53,24 @@
 	data.frame(dim = 'count', unit = 'mol', std = 1),
 
 	data.frame(dim = 'duration', unit = 'nsec', std = 1e9),
+	data.frame(dim = 'duration', unit = 'ns', std = 1e9),
 	data.frame(dim = 'duration', unit = 'usec', std = 1e6),
+	data.frame(dim = 'duration', unit = 'us', std = 1e6),
 	data.frame(dim = 'duration', unit = 'msec', std = 1e3),
+	data.frame(dim = 'duration', unit = 'ms', std = 1e3),
 	data.frame(dim = 'duration', unit = 'sec', std = 1),
+	data.frame(dim = 'duration', unit = 's', std = 1),
 	data.frame(dim = 'duration', unit = 'min', std = 1/60),
+	data.frame(dim = 'duration', unit = 'mins', std = 1/60),
 	data.frame(dim = 'duration', unit = 'hr', std = 1/3600),
 	data.frame(dim = 'duration', unit = 'hour', std = 1/3600),
+	data.frame(dim = 'duration', unit = 'hours', std = 1/3600),
 	data.frame(dim = 'duration', unit = 'day', std = 1/86400),
+	data.frame(dim = 'duration', unit = 'days', std = 1/86400),
 	data.frame(dim = 'duration', unit = 'wk', std = 1/604800),
 	data.frame(dim = 'duration', unit = 'week', std = 1/604800),
 	data.frame(dim = 'duration', unit = 'mon', std = 1/(86400*365.25/12)),
+	data.frame(dim = 'duration', unit = 'month', std = 1/(86400*365.25/12)),
 	data.frame(dim = 'duration', unit = 'yr', std = 1/(86400*365.25)),
 	data.frame(dim = 'duration', unit = 'year', std = 1/(86400*365.25)),
 	data.frame(dim = 'duration', unit = 'dec', std = 1/(86400*3652.5)),
@@ -104,6 +113,7 @@
 	data.frame(dim = 'flow', unit = 'l_per_min', std = 60),
 	data.frame(dim = 'flow', unit = 'LPM', std = 60),
 	data.frame(dim = 'flow', unit = 'l_per_hr', std = 3600),
+	data.frame(dim = 'flow', unit = 'LPH', std = 3600),
 	data.frame(dim = 'flow', unit = 'm3_per_sec', std = 1e-3),
 	data.frame(dim = 'flow', unit = 'm3_per_min', std = 1e-3*60),
 	data.frame(dim = 'flow', unit = 'm3_per_hr', std = 1e-3*3600),
@@ -112,9 +122,13 @@
 	data.frame(dim = 'flow', unit = 'gal_per_min', std = 1/3.785411784*60),
 	data.frame(dim = 'flow', unit = 'GPM', std = 1/3.785411784*60),
 	data.frame(dim = 'flow', unit = 'gal_per_hr', std = 1/3.785411784*3600),
+	data.frame(dim = 'flow', unit = 'GPH', std = 1/3.785411784*3600),
 	data.frame(dim = 'flow', unit = 'ft3_per_sec', std = 61.0237440947323/1728),
+	data.frame(dim = 'flow', unit = 'cuft_per_sec', std = 61.0237440947323/1728),
 	data.frame(dim = 'flow', unit = 'ft3_per_min', std = 61.0237440947323/1728*60),
+	data.frame(dim = 'flow', unit = 'cuft_per_min', std = 61.0237440947323/1728*60),
 	data.frame(dim = 'flow', unit = 'ft3_per_hr', std = 61.0237440947323/1728*3600),
+	data.frame(dim = 'flow', unit = 'cuft_per_hr', std = 61.0237440947323/1728*3600),
 	
 	data.frame(dim = 'length', unit = 'angstrom', std = 1e10),
 	data.frame(dim = 'length', unit = 'nm', std = 1e9),
@@ -123,8 +137,11 @@
 	data.frame(dim = 'length', unit = 'cm', std = 100),
 	data.frame(dim = 'length', unit = 'dm', std = 10),
 	data.frame(dim = 'length', unit = 'm', std = 1),
+	data.frame(dim = 'length', unit = 'meter', std = 1),
+	data.frame(dim = 'length', unit = 'metre', std = 1),
 	data.frame(dim = 'length', unit = 'km', std = 1e-3),
 	data.frame(dim = 'length', unit = 'inch', std = 100/2.54),
+	data.frame(dim = 'length', unit = 'in', std = 100/2.54),
 	data.frame(dim = 'length', unit = 'ft', std = 100/2.54/12),
 	data.frame(dim = 'length', unit = 'foot', std = 100/2.54/12),
 	data.frame(dim = 'length', unit = 'feet', std = 100/2.54/12),
@@ -135,6 +152,7 @@
 	data.frame(dim = 'length', unit = 'mile', std = 100/2.54/12/5280),
 	data.frame(dim = 'length', unit = 'naut_mi', std = 1/1852),
 	data.frame(dim = 'length', unit = 'au', std = 1/149597870700),
+	data.frame(dim = 'length', unit = 'AU', std = 1/149597870700),
 	data.frame(dim = 'length', unit = 'light_yr', std = 1/9460730472580800),
 	data.frame(dim = 'length', unit = 'light_year', std = 1/9460730472580800),
 	data.frame(dim = 'length', unit = 'parsec', std = 1/149597870700/(6.48e5/pi)),
@@ -156,6 +174,8 @@
 	data.frame(dim = 'mass', unit = 'metric_ton', std = 1e-6),
 	data.frame(dim = 'mass', unit = 'oz', std = 1/28.349523125),
 	data.frame(dim = 'mass', unit = 'lbs', std = 2.20462234e-3),
+	data.frame(dim = 'mass', unit = 'pound', std = 2.20462234e-3),
+	data.frame(dim = 'mass', unit = 'pounds', std = 2.20462234e-3),
 	data.frame(dim = 'mass', unit = 'short_ton', std = 1/907184.74),
 	data.frame(dim = 'mass', unit = 'long_ton', std = 1/1.016e6),
 	data.frame(dim = 'mass', unit = 'stone', std = 2.20462234e-3/14),
@@ -196,6 +216,7 @@
 	data.frame(dim = 'speed', unit = 'm_per_sec', std = 1),
 	data.frame(dim = 'speed', unit = 'km_per_sec', std = 1e-3),
 	data.frame(dim = 'speed', unit = 'inch_per_sec', std = 100/2.54),
+	data.frame(dim = 'speed', unit = 'in_per_sec', std = 100/2.54),
 	data.frame(dim = 'speed', unit = 'ft_per_sec', std = 100/2.54/12),
 	data.frame(dim = 'speed', unit = 'kph', std = 1e-3*3600),
 	data.frame(dim = 'speed', unit = 'km_per_hr', std = 1e-3*3600),
@@ -212,10 +233,19 @@
 	data.frame(dim = 'temperature', unit = 'K', std = NA),
 	data.frame(dim = 'temperature', unit = 'R', std = NA),
 	
+	data.frame(dim = 'torque', unit = 'N-m', std = 1),
+	data.frame(dim = 'torque', unit = 'ft-lbs', std = 0.73756215),
+	data.frame(dim = 'torque', unit = 'inch-lbs', std = 0.73756215*12),
+	data.frame(dim = 'torque', unit = 'in-lbs', std = 0.73756215*12),
+	
 	data.frame(dim = 'volume', unit = 'ul', std = 1e6),
+	data.frame(dim = 'volume', unit = 'uL', std = 1e6),
 	data.frame(dim = 'volume', unit = 'ml', std = 1e3),
+	data.frame(dim = 'volume', unit = 'mL', std = 1e3),
 	data.frame(dim = 'volume', unit = 'dl', std = 10),
+	data.frame(dim = 'volume', unit = 'dL', std = 10),
 	data.frame(dim = 'volume', unit = 'l', std = 1),
+	data.frame(dim = 'volume', unit = 'L', std = 1),
 	data.frame(dim = 'volume', unit = 'cm3', std = 1e3),
 	data.frame(dim = 'volume', unit = 'dm3', std = 1),
 	data.frame(dim = 'volume', unit = 'm3', std = 1e-3),
@@ -228,6 +258,7 @@
 	data.frame(dim = 'volume', unit = 'us_quart', std = 1/3.785411784*4),
 	data.frame(dim = 'volume', unit = 'us_gal', std = 1/3.785411784),
 	data.frame(dim = 'volume', unit = 'inch3', std = 61.0237440947323),
+	data.frame(dim = 'volume', unit = 'in3', std = 61.0237440947323),
 	data.frame(dim = 'volume', unit = 'ft3', std = 61.0237440947323/12^3),
 	data.frame(dim = 'volume', unit = 'mi3', std = 61.0237440947323/(12*5280)^3),
 	data.frame(dim = 'volume', unit = 'imp_tsp', std = 1/4.54609*768),
@@ -262,6 +293,7 @@ conv_unit_options = lapply(split(.conversions$unit, .conversions$dim, drop = TRU
 #'	 \item{Pressure}{uatm, atm, Pa, hPa, kPa, torr, mmHg, inHg, cmH2O, inH2O, mbar, bar, dbar, psi}
 #'	 \item{Speed}{mm_per_sec, cm_per_sec, m_per_sec, km_per_sec, inch_per_sec, ft_per_sec, kph, mph, km_per_day, mi_per_day, knot, mach, light}
 #'	 \item{Temperature}{C, F, K, R}
+#'	 \item{Torque}{N-m, ft-lbs, inch-lbs}
 #'	 \item{Volume}{ul, ml, dl, l, cm3, dm3, m3, km3, us_tsp, us_tbsp, us_oz, us_cup, us_pint, us_quart, us_gal, inch3, ft3, mi3, imp_tsp, imp_tbsp, imp_oz, imp_cup, imp_pint, imp_quart, imp_gal}
 #' }
 #' The conversion values have been defined based primarily from international weight and measurement authorities (e.g. General Conference on Weights and Measures, International Committee for Weights and Measures, etc.). While much effort was made to make conversions as accurate as possible, you should check the accuracy of conversions to ensure that conversions are precise enough for your applications.
